const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/index.umd-CyIWjNah.js","assets/index-CNhCN7f4.js","assets/index-CYGGGtBz.css"])))=>i.map(i=>d[i]);
import{_ as n,a as o,s as a}from"./index-CNhCN7f4.js";function _(i){return n(this,void 0,void 0,function(){var t;return o(this,function(e){switch(e.label){case 0:return[4,a(()=>import("./index.umd-CyIWjNah.js").then(r=>r.i),__vite__mapDeps([0,1,2]))];case 1:return t=e.sent(),i._plugins=t,[2]}})})}export{_ as loadLegacyVideoPlugins};
